@@ -2,7 +2,7 @@
 "Release information about pycerberus."
 
 name = 'pycerberus'
-version = '0.1'
+version = '0.2'
 description = 'Highly flexible, no magic input validation library'
 long_description = '''
 pycerberus is a framework to check user data thoroughly so that you can protect
@@ -29,6 +29,15 @@ your application from malicious (or just garbled) input data.
 Changelog
 ******************************
 
+0.2 (16.03.2010)
+==================
+- You now can declare custom messages as a class-level dict
+- Added interface to retrieve error details from InvalidDataErrors
+- Added validation schemas to validate a set of values (typically a web form).
+  Schemas can also inherit from other schemas to avoid code duplication.
+- Validators try to make thread-safety violations obvious
+- Nicer API to retrieve error details from an InvalidDataError
+
 0.1 (30.01.2010)
 ==================
  - initial release
