@@ -17,12 +17,27 @@ class ValidatorWithCustomMessageForKey(Validator):
         return 'message from custom lookup'
 
 
-
 class CustomValidatorAPITest(ValidationTest):
     
     validator_class = ValidatorWithCustomMessageForKey
     
     def test_validators_can_custom_lookup_mechanism_for_messages(self):
-        self.assert_equals('message from custom lookup', self.message_for_key('inactive', locale='en'))
+        self.assert_equals('message from custom lookup', self.message_for_key('inactive'))
+
+
+
+class CanDeclareMessagesInClassDictValidator(Validator):
+    messages = {'classlevel': 'Message from class-level.'}
+    
+    def validate(self, value, context):
+        self.error('classlevel', value, context)
+
+
+class CanDeclareMessagesInClassDictTest(ValidationTest):
+    
+    validator_class = CanDeclareMessagesInClassDictValidator
+    
+    def test_can_declare_messages_in_classdict(self):
+        self.assert_equals('Message from class-level.', self.message_for_key('classlevel'))
 
 
