@@ -22,6 +22,6 @@ class StringValidatorTest(ValidationTest):
     
     def test_show_class_name_in_error_message(self):
         e = self.assert_raises(InvalidDataError, self.process, [])
-        self.assert_true(u'(expected string, got "list")' in e.msg, e.msg)
+        self.assert_contains(u'(expected string, got "list")', e.details().msg())
 
 
